#include <QApplication>
#include <QDebug>
#include <QStringList>
#include <QClipboard>
#include <QDir>
#include <QIcon>
#include <QImage>
#include <QLabel>
#include <QVBoxLayout>
#include <QGroupBox>
#include <QFontMetrics>
#include <QVBoxLayout>
#include <QPainter>
#include <QFileInfo>

int optSize = 16;
QImage::Format optFormat = QImage::Format_ARGB32;

#if QT_VERSION < 0x050000
QDebug operator<<(QDebug d, const QImage &w)
{
    d << w.size() << "format=" << w.format() << "depth" << w.depth();
    return d;
}
#endif

static QImage createImage()
{
    QImage image(optSize, optSize, optFormat);
    image.fill(image.hasAlphaChannel() ? Qt::transparent : Qt::white);

    QPainter p(&image);
    if (image.hasAlphaChannel())
        p.fillRect(QRect(QPoint(0, 0), QSize(optSize / 2, optSize)), Qt::white);
    p.drawRect(QRect(QPoint(0, 0), image.size() - QSize(1, 1)));
    p.drawLine(0, 0, optSize, optSize);
    p.drawLine(0, optSize, optSize, 0);
    QString qtv = QT_VERSION_STR;
    qtv.remove('.');
    qtv.truncate(2);
//    qtv += '_';
//    qtv += QString::number(optFormat);
    const QRect rect = QFontMetrics(p.font()).tightBoundingRect(qtv);
    const QPoint pos((optSize - rect.width()) / 2,
                     optSize - (optSize - rect.height()) / 2);
    p.drawText(pos, qtv);
    return image;
}

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QStringList args = QCoreApplication::arguments();
    args.pop_front();
    qDebug() << QT_VERSION_STR << args;

    int idx = args.indexOf("-w");
    if (idx >= 0)
        optSize = args.at(idx + 1).toInt();
    idx = args.indexOf("-f");
    if (idx >= 0)
        optFormat = static_cast<QImage::Format>(args.at(idx + 1).toInt());

    const QImage src = createImage();

    QApplication::clipboard()->setImage(src);
    qDebug() << "COPIED"<< src;

    QGroupBox b("QTBUG-42265");
    b.setMinimumWidth(200);
    b.setWindowTitle(QT_VERSION_STR);
    QHBoxLayout *lt = new QHBoxLayout(&b);

    QLabel *l = new QLabel(&b);
    lt->addWidget(l);
    l->setPixmap(QPixmap::fromImage(src));

    b.show();

    return QApplication::exec();
}
